Stellar Models (``taurex.stellar``)
===================================

Base
-------------------------------

.. autoclass:: taurex.data.stellar.star.Star
   :members:
   :undoc-members:
   :show-inheritance:

Blackbody
-------------------------------

.. autoclass:: taurex.data.stellar.star.BlackbodyStar
   :members:
   :undoc-members:
   :show-inheritance:

PHOENIX
-------

.. automodule:: taurex.data.stellar.phoenix
   :members:
   :undoc-members:
   :show-inheritance:
